<?php
//
// Nagios XI Operations Center Component
// Copyright (c) 2011-2020 Nagios Enterprises, LLC. All rights reserved.
//

require_once(dirname(__FILE__) . '/../../common.inc.php');

// Initialization and session start
pre_init();
init_session();
grab_request_vars();
check_prereqs();

// Check authentication
check_authentication(false);

// Grab page variables
$host = grab_request_var("host", "");
$service = grab_request_var("service", "");
$hostgroup = grab_request_var("hostgroup", "");
$servicegroup = grab_request_var("servicegroup", "");
$state = grab_request_var("state", "");

// Grab extra filters
$filters = grab_request_var('filters', array());
$update_flag = grab_request_var('update_flag', 0);
$clear = grab_request_var('clear', 0);
if ($clear) {
    $filters = array();
    $update_flag = 1;
}

// If the user clicked the update button, set user metas
if ($update_flag) {
    // If the hide_not_dis is in the array, the user has turned that filter on
    if (in_array('hide_not_dis', $filters)) {
        // Turn filter on
        set_user_meta(0, 'nocscreen_hide_not_disabled', 1, false);
    } else {
        set_user_meta(0, 'nocscreen_hide_not_disabled', 0, false);
    }

    // If the hide_handled is in the array, the user has turned that filter on
    if (in_array('hide_handled', $filters)) {
        // Turn filter on
        set_user_meta(0, 'nocscreen_hide_handled', 1, false);
    } else {
        set_user_meta(0, 'nocscreen_hide_handled', 0, false);
    }

    // If the hide_soft is in the array, the user has turned that filter on
    if (in_array('hide_soft', $filters)) {
        // Turn filter on
        set_user_meta(0,'nocscreen_hide_soft_states', 1, false);
    } else {
        set_user_meta(0,'nocscreen_hide_soft_states', 0, false);
    }
}

// Grab user metas after they have been updated
// ** There is probably a better way to do this **
$hide_not_dis = get_user_meta(0, 'nocscreen_hide_not_disabled');
$hide_handled = get_user_meta(0, 'nocscreen_hide_handled');
$hide_soft = get_user_meta(0, 'nocscreen_hide_soft_states');
$host_orderby = get_user_meta(0, 'nocscreen_host_orderby', "last_state_change:a");
$service_orderby = get_user_meta(0, 'nocscreen_service_orderby', "last_state_change:a");
$show_filters = get_user_meta(0, 'nocscreen_show_filters', 1);

$refresh = intval(get_user_meta(0, 'nocscreen_page_refresh', 10));
if ($refresh < 1) {
    $refresh = 1;
}

$title = _("Operations Center");
do_page_start(array("page_title" => $title, "jquery_plugins" => array("sumoselect")), true);
?>

<style type="text/css">
    #topbar { margin-top: 10px; vertical-align: top; }
    h1 { margin: 0; padding: 0; }
    h1 img { margin-right: 10px; }
    #leftside { float: left; }
    #rightside { float: right; }
    .strong { font-weight: bold; }
    #lastUpdate { color: #777; font-size: 11px; margin: 10px 0; }
    div.duration { width: 125px; }
    #noc_filter{ margin: 0; }
    .noc-filters { margin: 5px 0 15px 0; }
    .filters-btn { margin-left: 10px; }
    /* Sometimes the OK button has camelcase, sometimes it doesn't. Don't ask me why. */
    .btnOk {background-color: #4D89F9; border-color: #3371E6; color: white;}
    .btnOk:hover {background-color: #3371E6 !important;}
    .btnok {background-color: #4D89F9; border-color: #3371E6; color: white;}
    .btnok:hover {background-color: #3371E6 !important;}
</style>

<script type="text/javascript">
var INT_ID;
$(document).ready(function () {

    //$('.refresh').html('<i class="fa fa-spinner fa-14 fa-spin"></i>');

    // Initialize our sumoselects
    // These are all done independently so we can act upon them more easily
    extraFilterSelect = $('#extra-filters-select').SumoSelect({
        okCancelInMulti: true,
        captionFormatAllSelected: "<?php echo _('All filters selected'); ?>",
        csvDispCount: 2,
        placeholder: '<?php echo _('Select Additional Filters'); ?>'
    });

    stateSelect = $('#state-select').SumoSelect({});

    hostSelect = $('#host-select').SumoSelect({
        triggerChangeCombined: true,
        csvDispCount: 2,
        search: true,
        searchText: 'Search...'
    });

    serviceSelect = $('#service-select').SumoSelect({
        triggerChangeCombined: true,
        csvDispCount: 2,
        search: true,
        searchText: 'Search...'
    });

    servicegroupSelect = $('#servicegroup-select').SumoSelect({
        triggerChangeCombined: true,
        csvDispCount: 2,
        search: true,
        searchText: 'Search...'
    });

    hostgroupSelect = $('#hostgroup-select').SumoSelect({
        triggerChangeCombined: true,
        csvDispCount: 2,
        search: true,
        searchText: 'Search...'
    });

    // Main NOC content and loop
    noc_load_content();
    INT_ID = setInterval(noc_load_content, <?php echo intval($refresh) * 1000; ?>);

    // Hide/show filters
    $('.filters-btn').click(function() {
        if ($('.noc-filters').is(':visible')) {
            $('.noc-filters').hide();
            $('.filters-btn').html('<i class="fa fa-filter"></i> <?php echo _("Show Filters"); ?>');
            $.post('nocscreenapi.php', { 'cmd': 'setfilter', 'show': 0 });
        } else {
            $('.noc-filters').show();
            $('.filters-btn').html('<i class="fa fa-filter"></i> <?php echo _("Hide Filters"); ?>');
            $.post('nocscreenapi.php', { 'cmd': 'setfilter', 'show': 1 });
        }
    });

    // Clear hostgroup and servicegroup selects if a host is selected
    $(hostSelect).change(function ()
    {
        // Check for empty string to avoid infinite loop
        if ($(this).val() !== '') {
            // Clear the hostgroup select
            $('#hostgroup-select > .placeholder').prop('disabled', false);
            hostgroupSelect.sumo.selectItem('');
            hostgroupSelect.sumo.unSelectAll();
            $('#hostgroup-select > .placeholder').prop('disabled', true);
            hostgroupSelect.sumo.reload();

            // Clear the servicegroup
            $('#servicegroup-select > .placeholder').prop('disabled', false);
            servicegroupSelect.sumo.selectItem('');
            servicegroupSelect.sumo.unSelectAll();
            $('#servicegroup-select > .placeholder').prop('disabled', true);
            servicegroupSelect.sumo.reload();
        } else {
            return;
        }
    });

    // Clear host and servicegroup selects if a hostgroup is selected
    $(hostgroupSelect).change(function ()
    {
        // Check for empty string to avoid infinite loop
        if ($(this).val() !== '') {
            // Clear the host select
            $('#host-select > .placeholder').prop('disabled', false);
            hostSelect.sumo.selectItem('');
            hostSelect.sumo.unSelectAll();
            $('#host-select > .placeholder').prop('disabled', true);
            hostSelect.sumo.reload();

            // Clear the servicegroup
            $('#servicegroup-select > .placeholder').prop('disabled', false);
            servicegroupSelect.sumo.selectItem('');
            servicegroupSelect.sumo.unSelectAll();
            $('#servicegroup-select > .placeholder').prop('disabled', true);
            servicegroupSelect.sumo.reload();
        } else {
            return false;
        }
        
    });

    // Clear host and servicegroup selects if a hostgroup is selected
    $(servicegroupSelect).change(function ()
    {
        // Check for empty string to avoid infinite loop
        if ($(this).val() !== '') {
            // Clear the host select
            $('#host-select > .placeholder').prop('disabled', false);
            hostSelect.sumo.selectItem('');
            hostSelect.sumo.unSelectAll();
            $('#host-select > .placeholder').prop('disabled', true);
            hostSelect.sumo.reload();

            // Clear the servicegroup
            $('#hostgroup-select > .placeholder').prop('disabled', false);
            hostgroupSelect.sumo.selectItem('');
            hostgroupSelect.sumo.unSelectAll();
            $('#hostgroup-select > .placeholder').prop('disabled', true);
            hostgroupSelect.sumo.reload();
        } else {
            return false;
        }

    });
    
    $('#hosttable .host_order').live('click', function() {
        $('#orderby_update').val(1);
        if ($('#host_orderby').val() == 'name:a') {
            $('#host_orderby').val('name:d');
        } else {
            $('#host_orderby').val('name:a');
        }
        noc_load_content();
    });
    
    $('#hosttable .duration_order').live('click', function() {
        $('#orderby_update').val(1);
        if ($('#host_orderby').val() == 'last_state_change:a') {
            $('#host_orderby').val('last_state_change:d');
        } else {
            $('#host_orderby').val('last_state_change:a');
        }
        noc_load_content();
    });
    
    $('#servicetable .host_order').live('click', function() {
        $('#orderby_update').val(1);
        if ($('#service_orderby').val() == 'host_name:a') {
            $('#service_orderby').val('host_name:d');
        } else {
            $('#service_orderby').val('host_name:a');
        }
        noc_load_content();
    });
    
    $('#servicetable .service_order').live('click', function() {
        $('#orderby_update').val(1);
        if ($('#service_orderby').val() == 'service_description:a') {
            $('#service_orderby').val('service_description:d');
        } else {
            $('#service_orderby').val('service_description:a');
        }
        noc_load_content();
    });
    
    $('#servicetable .duration_order').live('click', function() {
        $('#orderby_update').val(1);
        if ($('#service_orderby').val() == 'last_state_change:a') {
            $('#service_orderby').val('last_state_change:d');
        } else {
            $('#service_orderby').val('last_state_change:a');
        }
        noc_load_content();
    });

    $('#submit-button').click(function() {
        $('#noc_filter').append('<input type="hidden" id="update-flag" name="update_flag" value="1"/>');
    })

    // Settings dropdown
    $('.btn-update-settings').click(function() {
        var refresh = parseInt($('.page-refresh').val());
        if (refresh) {
            clearInterval(INT_ID);
            var rval = refresh * 1000;
            INT_ID = setInterval(noc_load_content, rval);

            // Set refresh value in user meta
            $.post('nocscreenapi.php', { 'cmd': 'setrefresh', 'refresh': refresh });
        }
        $("#settings-dropdown").fadeOut("fast");
    });

    $('.btn-close-settings').click(function() {
        $("#settings-dropdown").fadeOut("fast");
    });

    if ($('#open-dtform').length > 0) {
        var p = $('#open-dtform').position();
        var left = Math.floor(p.left+8) - ($('#settings-dropdown').outerWidth()/2);
        var top = Math.floor(p.top+14);
        $('#settings-dropdown').css('left', left+'px');
        $('#settings-dropdown').css('top', top+'px');

        $("#open-dtform").click(function () {
            var d = $("#settings-dropdown").css("display");
            if (d == "none") {
                $("#settings-dropdown").fadeIn("fast");
            } else {
                $("#settings-dropdown").fadeOut("fast");
            }
        });
    }

});

function noc_load_content()
{
    var datastring = $("#noc_filter").serialize();

    // Summary bar info
    $.ajax({
        url: 'nocscreenapi.php?summary=true',
        data: datastring
    }).done(function (html) {
        $('#rightside').html(html);
    });

    // Get orderby settings
    datastring += '&orderby_update=' + $('#orderby_update').val();
    datastring += '&host_orderby=' + $('#host_orderby').val();
    datastring += '&service_orderby=' + $('#service_orderby').val();
    $('#orderby_update').val(0);

    // Main NOC content
    $.ajax({
        url: 'nocscreenapi.php',
        data: datastring
    }).done(function (html) {
        var d = new Date();
        $('#lastUpdate').empty();
        $('#lastUpdate').append(('Last Update: ' + d.toString() ));
        $('#content').html(html);
    });

}
</script>

<?php
// Include graph explorer if we have it
if (function_exists('graphexplorer_component_js_include')) {
    graphexplorer_component_js_include();
}
?>

<div id="topbar">
    <div id="leftside">
        <img src="<?php echo theme_image('nagiosxi-logo-small.png'); ?>" class="fl" alt="<?php echo _("Nagios XI"); ?>">
        <h1 class="fl" style="margin: 0 15px;"><?php echo _("Operations Center"); ?></h1>
        <a class="tt-bind settings-dropdown" id="open-dtform" data-placement="right" title="<?php echo _('Edit page settings'); ?>"><img src="<?php echo theme_image('cog.png'); ?>"></a>
        <div id="settings-dropdown">
            <div class="content">
                <div class="input-group" style="width: 200px;">
                    <label class="input-group-addon"><?php echo _('Refresh every'); ?></label>
                    <input type="text" class="page-refresh form-control" value="<?php echo $refresh; ?>" placeholder="30">
                    <label class="input-group-addon"><?php echo _('sec'); ?></label>
                </div>
                <div style="margin-top: 10px">
                    <button type="button" class="btn btn-update-settings btn-xs btn-primary fl"><i class="fa fa-check fa-l"></i> <?php echo _('Update'); ?></button>
                    <button type="button" class="btn btn-close-settings btn-xs btn-default fr"><i class="fa fa-times"></i> <?php echo _('Close'); ?></button>
                    <div class="clear"></div>
                </div>
            </div>
        </div>
        <button type="button" class="filters-btn btn btn-xs btn-default"><i class="fa fa-filter"></i> <?php if ($show_filters) { echo _('Hide Filters'); } else { echo _('Show Filters'); } ?></button>
        <div class="clear"></div>
        <div id="lastUpdate"></div>
    </div>
    <div id="rightside"></div>
    <div class="clear"></div>
</div>

<div class="noc-filters well" <?php if (!$show_filters) { echo 'style="display: none;"'; } ?>>    
    <form id="noc_filter" class="form-inline" method="get" action="">

        <div class="input-group">
            <label class="input-group-addon"><?php echo _('Host'); ?></label>
            <select class="hide" style="width: 150px;" name="host" id="host-select">
                <option value="">&nbsp;</option>
                <?php
                $args = array('brevity' => 1, 'orderby' => 'host_name:a');
                $oxml = get_xml_host_objects($args);
                if ($oxml) {
                    foreach ($oxml->host as $hostobject) {
                        $name = strval($hostobject->host_name);
                        echo "<option value='" . $name . "' " . is_selected($host, $name) . ">$name</option>\n";
                    }
                }
                ?>
            </select>
        </div>
 
        <div class="input-group">
            <label class="input-group-addon"><?php echo _('Hostgroup'); ?></label>
            <select class="hide" style="width: 150px;" name="hostgroup" id="hostgroup-select">
                <option value="">&nbsp;</option>
                <?php
                $args = array('orderby' => 'hostgroup_name:a');
                $oxml = get_xml_hostgroup_objects($args);
                if ($oxml) {
                    foreach ($oxml->hostgroup as $hg) {
                        $name = strval($hg->hostgroup_name);
                        echo "<option value='" . $name . "' " . is_selected($hostgroup, $name) . ">$name</option>\n";
                    }
                }
                ?>
            </select>
        </div>

        <div class="input-group">
            <label class="input-group-addon"><?php echo _('Servicegroup'); ?></label>
            <select class="hide" style="width: 150px;" name="servicegroup" id="servicegroup-select">
                <option value="">&nbsp;</option>
                <?php
                $args = array('orderby' => 'servicegroup_name:a');
                $oxml = get_xml_servicegroup_objects($args);
                if ($oxml) {
                    foreach ($oxml->servicegroup as $sg) {
                        $name = strval($sg->servicegroup_name);
                        echo "<option value='" . $name . "' " . is_selected($servicegroup, $name) . ">$name</option>\n";
                    }
                }
                ?>
            </select>
        </div>

        <div class="input-group">
            <label class="input-group-addon"><?php echo _('Service State'); ?></label>
            <select class="hide" style="width: 100px;" name="state" id="state-select">
                <option value="">&nbsp;</option>
                <option value="1" <?php echo is_selected($state, 1); ?> ><?php echo _('Warning') ?></option>
                <option value="2" <?php echo is_selected($state, 2); ?> ><?php echo _('Critical') ?></option>
                <option value="3" <?php echo is_selected($state, 3); ?> ><?php echo _('Unknown') ?></option>
            </select>
        </div>

        <div class="input-group">
            <label class="input-group-addon"><?php echo _('Additional Filters'); ?></label>
            <select class="hide" style="width: 200px;" name="filters[]" id="extra-filters-select" multiple>
                <option value="hide_not_dis" <?php echo is_selected($hide_not_dis, 1); ?> ><?php echo _('Hide notifications disabled') ?></option>
                <option value="hide_handled" <?php echo is_selected($hide_handled, 1); ?> ><?php echo _('Hide handled') ?></option>
                <option value="hide_soft" <?php echo is_selected($hide_soft, 1); ?> ><?php echo _('Hide soft states') ?></option>
            </select>
        </div>

        <button type="submit" class="reporttimesubmitbutton btn btn-sm btn-primary" style="vertical-align: top;" name="reporttimesubmitbutton" id="submit-button"><i class="fa fa-check"></i> <?php echo _("Filter"); ?></button>
        <a href="noc.php?clear=1" class="btn btn-sm btn-default"><i class="fa fa-times"></i> <?php echo _('Clear filters'); ?></a>

    </form>

    <!-- These are just here to be accessed -->
    <input id="host_orderby" type="hidden" name="host_orderby" value="<?php echo $host_orderby; ?>">
    <input id="service_orderby" type="hidden" name="service_orderby" value="<?php echo $service_orderby; ?>">
    <input id="orderby_update" type="hidden" name="orderby_update" value="0">

    <div class="clear"></div>
</div>

<div id="content"></div>

<?php
do_page_end(true);
